==> estateplat-common-1.2.4-20210518.012322-756-sources.jar: cn/gtmap/estateplat/model/server/core/BdcNydJyq.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @description 农用地经营权
 */
@Table(name = "bdc_nydjyq")
public class BdcNydJyq extends QllxParent implements InsertVo, QllxVo {


    private static final long serialVersionUID = -6340433632926163991L;

    private String bdcdyh;//	不动产单元号
    private String bdcdybh;//	不动产单元编号
    private String zl;//	坐落
    private Date jyqqssj;//	承包经营起始时间
    private Date jyqjssj;//	承包经营结束时间
    private String bz;//	备注
    private Double jyqmj;//经营面积（平方米）
    private String htbh;//合同编号
    private Double htje;//合同金额
    private Double ccgd;//草层高度
    private String cdysz;//草地优势种
    private String cdjq;//草地建群
    private String cdfgd;//草地覆盖度
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private String tdsyqxz;//土地所有权性质
    private String fbfmc;//发包方名称
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号

    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String qlqtzk; //权利其他状况


    @Override
    public String getQlqtzk() {
        return qlqtzk;
    }

    @Override
    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    @Override
    public Date getDjsj() {
        return djsj;
    }

    @Override
    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @Override
    public String getDbr() {
        return dbr;
    }

    @Override
    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Date getJyqqssj() {
        return jyqqssj;
    }

    public void setJyqqssj(Date jyqqssj) {
        this.jyqqssj = jyqqssj;
    }

    public Date getJyqjssj() {
        return jyqjssj;
    }

    public void setJyqjssj(Date jyqjssj) {
        this.jyqjssj = jyqjssj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getJyqmj() {
        return jyqmj;
    }

    public void setJyqmj(Double jyqmj) {
        this.jyqmj = jyqmj;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

    public String getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(String cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }
}

==> estateplat-common-1.2.4-20210809.023003-835-sources.jar: cn/gtmap/estateplat/model/server/core/BdcNydJyq.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @description 农用地经营权
 */
@Table(name = "bdc_nydjyq")
public class BdcNydJyq extends QllxParent implements InsertVo, QllxVo {


    private static final long serialVersionUID = -6340433632926163991L;

    private String bdcdyh;//	不动产单元号
    private String bdcdybh;//	不动产单元编号
    private String zl;//	坐落
    private Date jyqqssj;//	承包经营起始时间
    private Date jyqjssj;//	承包经营结束时间
    private String bz;//	备注
    private Double jyqmj;//经营面积（平方米）
    private String htbh;//合同编号
    private Double htje;//合同金额
    private Double ccgd;//草层高度
    private String cdysz;//草地优势种
    private String cdjq;//草地建群
    private String cdfgd;//草地覆盖度
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private String tdsyqxz;//土地所有权性质
    private String fbfmc;//发包方名称
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号

    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String qlqtzk; //权利其他状况
    private String jyyt; //经营用途
    private String jyfw;//	经营范围
    private Double scmj;//实测面积
    @Override
    public String getQlqtzk() {
        return qlqtzk;
    }

    @Override
    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    @Override
    public Date getDjsj() {
        return djsj;
    }

    @Override
    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @Override
    public String getDbr() {
        return dbr;
    }

    @Override
    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Date getJyqqssj() {
        return jyqqssj;
    }

    public void setJyqqssj(Date jyqqssj) {
        this.jyqqssj = jyqqssj;
    }

    public Date getJyqjssj() {
        return jyqjssj;
    }

    public void setJyqjssj(Date jyqjssj) {
        this.jyqjssj = jyqjssj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getJyqmj() {
        return jyqmj;
    }

    public void setJyqmj(Double jyqmj) {
        this.jyqmj = jyqmj;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

    public String getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(String cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }
}
